#
# spec file for package stax2-api
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           stax2-api
Version:        4.2.1
Release:        2.9
Summary:        Experimental API extending basic StAX implementation
License:        BSD-2-Clause
Group:          Development/Libraries/Java
URL:            http://wiki.fasterxml.com/WoodstoxStax2
Source0:        https://github.com/FasterXML/%{name}/archive/%{name}-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  java-devel >= 1.8
BuildRequires:  maven-local
BuildRequires:  mvn(com.fasterxml:oss-parent:pom:)
BuildRequires:  mvn(org.apache.felix:maven-bundle-plugin)
BuildArch:      noarch

%description
StAX2 is an experimental API that is intended to extend
basic StAX specifications in a way that allows implementations
to experiment with features before they end up in the actual
StAX specification (if they do). As such, it is intended
to be freely implementable by all StAX implementations same way
as StAX, but without going through a formal JCP process.

%package javadoc
Summary:        API documentation for %{name}
Group:          Documentation/HTML

%description javadoc
This package contains the API documentation for %{name}.

%prep
%setup -q -n %{name}-%{name}-%{version}

%pom_xpath_remove pom:Import-Package

%pom_remove_plugin :maven-javadoc-plugin
%pom_remove_plugin :moditect-maven-plugin

%build
%{mvn_file} :%{name} %{name}
%{mvn_build} -f -- \
%if %{?pkg_vcmp:%pkg_vcmp java-devel >= 9}%{!?pkg_vcmp:0}
    -Dmaven.compiler.release=8 \
%endif
    -Dproject.build.outputTimestamp=$(date -u -d @${SOURCE_DATE_EPOCH:-$(date +%%s)} +%%Y-%%m-%%dT%%H:%%M:%%SZ) \
    -Dsource=8

%install
%mvn_install
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles

%files javadoc -f .mfiles-javadoc

%changelog
* Sat Sep  9 2023 Fridrich Strba <fstrba@suse.com>
- Reproducible builds: use SOURCE_DATE_EPOCH for timestamp
* Fri Aug 25 2023 Fridrich Strba <fstrba@suse.com>
- Update to version 4.2.1
  * 4.2.1 (14-May-2020)
    + #12: Fix to XML declaration write when 'standaloneSet' is
    specified
  * 4.2 (13-Mar-2019)
    + #15: Add Java 9+ module info using Moditect
    + Increase visibility of some of methods of
    'Stax2EventReaderImpl'
  * 4.1 (28-Mar-2018)
    + Add 'Automatic-Module-Name' for Java 9
    + Upgrade JDK baseline requirement Java 6 (from Java 5);
    + remove 'stax-api' dependency (since bundled on Java 6)
* Wed Mar 23 2022 Fridrich Strba <fstrba@suse.com>
- Build with java source and target levels 8
* Sun Nov 24 2019 Fridrich Strba <fstrba@suse.com>
- Specify maven.compiler.release to fix build with jdk9+ and newer
  maven-javadoc-plugin
* Thu Nov 21 2019 Fridrich Strba <fstrba@suse.com>
- Use default maven-compiler-plugin configuration to avoid 1.5
  as source/target levels
* Fri May  3 2019 Fridrich Strba <fstrba@suse.com>
- Intial packaging of stax2-api 4.0.0
